import { Seg, DateMarker, EventSegUiInteractionState, Slicer, DateRange, DateEnv, Splitter, DateSpan, EventDef, DateComponent, ViewProps, DateProfile, DayTableCell, Hit, BaseComponent, DateProfileGenerator, DayTableModel } from '@fullcalendar/core/internal';
import { Duration } from '@fullcalendar/core';
import { createElement, Ref, ComponentChild } from '@fullcalendar/core/preact';
import { TableSeg } from '@fullcalendar/daygrid/internal';

interface TimeColsSeg extends Seg {
    col: number;
    start: DateMarker;
    end: DateMarker;
}
declare function splitSegsByCol(segs: TimeColsSeg[] | null, colCnt: number): TimeColsSeg[][];
declare function splitInteractionByCol(ui: EventSegUiInteractionState | null, colCnt: number): EventSegUiInteractionState[];

declare class DayTimeColsSlicer extends Slicer<TimeColsSeg, [DateRange[]]> {
    sliceRange(range: DateRange, dayRanges: DateRange[]): TimeColsSeg[];
}

interface TimeSlatMeta {
    date: DateMarker;
    time: Duration;
    key: string;
    isoTimeStr: string;
    isLabeled: boolean;
}
declare function buildSlatMetas(slotMinTime: Duration, slotMaxTime: Duration, explicitLabelInterval: Duration | null, slotDuration: Duration, dateEnv: DateEnv): TimeSlatMeta[];

declare class AllDaySplitter extends Splitter {
    getKeyInfo(): {
        allDay: {};
        timed: {};
    };
    getKeysForDateSpan(dateSpan: DateSpan): string[];
    getKeysForEventDef(eventDef: EventDef): string[];
}

declare class TimeGridView extends DateComponent<ViewProps> {
    private createDayHeaderFormatter;
    private buildTimeColsModel;
    private buildDayRanges;
    private splitFgEventSegs;
    private splitBgEventSegs;
    private splitBusinessHourSegs;
    private splitNowIndicatorSegs;
    private splitDateSelectionSegs;
    private splitEventDrag;
    private splitEventResize;
    private allDaySplitter;
    private dayTableSlicer;
    private dayTimeColsSlicer;
    render(): createElement.JSX.Element;
}

interface TimeGridLayoutProps<HeaderCellModel, HeaderCellKey> {
    dateProfile: DateProfile;
    nowDate: DateMarker;
    todayRange: DateRange;
    cells: DayTableCell[];
    forPrint: boolean;
    isHitComboAllowed?: (hit0: Hit, hit1: Hit) => boolean;
    className: string;
    headerTiers: HeaderCellModel[][];
    renderHeaderLabel: (tier: number, innerWidthRef: Ref<number>, innerHeightRef: Ref<number>, width: number | undefined) => ComponentChild;
    renderHeaderContent: (model: HeaderCellModel, tier: number, innerHeightRef: Ref<number>, width: number | undefined) => ComponentChild;
    getHeaderModelKey: (model: HeaderCellModel) => HeaderCellKey;
    fgEventSegs: TableSeg[];
    bgEventSegs: TableSeg[];
    businessHourSegs: TableSeg[];
    dateSelectionSegs: TableSeg[];
    eventDrag: EventSegUiInteractionState | null;
    eventResize: EventSegUiInteractionState | null;
    fgEventSegsByCol: TimeColsSeg[][];
    bgEventSegsByCol: TimeColsSeg[][];
    businessHourSegsByCol: TimeColsSeg[][];
    nowIndicatorSegsByCol: TimeColsSeg[][];
    dateSelectionSegsByCol: TimeColsSeg[][];
    eventDragByCol: EventSegUiInteractionState[];
    eventResizeByCol: EventSegUiInteractionState[];
    eventSelection: string;
}
declare class TimeGridLayout<HeaderCellModel, HeaderCellKey> extends BaseComponent<TimeGridLayoutProps<HeaderCellModel, HeaderCellKey>> {
    private buildSlatMetas;
    private dayScrollerRef;
    private timeScrollerRef;
    private slatHeight?;
    private currentSlatCnt?;
    render(): createElement.JSX.Element;
    componentDidMount(): void;
    componentDidUpdate(prevProps: TimeGridLayoutProps<unknown, unknown>): void;
    componentWillUnmount(): void;
    private handleSlatHeight;
    private handleSize;
    private timeScrollResponder;
}

interface TimeGridWeekNumberProps {
    dateProfile: DateProfile;
    width: number | undefined;
    innerWidthRef?: Ref<number>;
    innerHeightRef?: Ref<number>;
}
declare class TimeGridWeekNumber extends BaseComponent<TimeGridWeekNumberProps> {
    private innerElRef;
    private detachInnerSize?;
    render(): createElement.JSX.Element;
    componentDidMount(): void;
    componentWillUnmount(): void;
}

declare function buildTimeColsModel(dateProfile: DateProfile, dateProfileGenerator: DateProfileGenerator): DayTableModel;
declare function buildDayRanges(dayTableModel: DayTableModel, dateProfile: DateProfile, dateEnv: DateEnv): DateRange[];

export { AllDaySplitter, DayTimeColsSlicer, TimeColsSeg, TimeGridLayout, TimeGridLayoutProps, TimeGridView, TimeGridWeekNumber, TimeSlatMeta, buildDayRanges, buildSlatMetas, buildTimeColsModel, splitInteractionByCol, splitSegsByCol };
